@@ -1,5 +1,11 @@
-import pandas as pd
+from datetime import datetime
+from typing import Union
 
+import pandas as pd
+from google.api_core import page_iterator
+from google.cloud.bigquery import job
+
+from airflow_commons.internal.bigquery.constants import STATE_FILTERS
 from airflow_commons.resources.glossary import COMMA, WHITE_SPACE
 from airflow_commons.logger import get_logger
 from airflow_commons.resources.bigquery import (
@@ -12,6 +18,7 @@ from airflow_commons.internal.bigquery.defaults import (
     TIMEOUT,
     LOCATION,
     SELECT_RETURN_TYPE,
+    STATE_FILTER,
 )
 from airflow_commons.internal.bigquery.core import (
     get_time_partition_field,
@@ -34,10 +41,11 @@ from airflow_commons.internal.util.time_utils import get_buffered_timestamp
 
 
 class BigqueryOperator(object):
-    def __init__(self, service_account_file: str):
+    def __init__(self, service_account_file: str, enable_logging=False):
         """
         Initializes a BigqueryOperator instance
         :param service_account_file: relative location of service account file
+        :param enable_logging: boolean value for enabling to log queries, by default is false
         :return:
         """
         self.ARCHIVE_MODES = ["INSERT", "UPSERT"]
@@ -46,6 +54,7 @@ class BigqueryOperator(object):
         self.DEFAULT_TIME_COLUMNS = ["last_updated_at", "processed_at"]
         self.client = connect(service_account_file)
         self.logger = get_logger("BigqueryOperator")
+        self.enable_logging = enable_logging
 
     def deduplicate(
         self,
@@ -154,6 +163,7 @@ class BigqueryOperator(object):
             sql=sql,
             timeout=timeout,
             location=location,
+            enable_logging=self.enable_logging,
         )
 
     def upsert(
@@ -209,6 +219,7 @@ class BigqueryOperator(object):
             sql=sql,
             timeout=timeout,
             location=location,
+            enable_logging=self.enable_logging,
         )
 
     def insert(
@@ -264,6 +275,7 @@ class BigqueryOperator(object):
             sql=sql,
             timeout=timeout,
             location=location,
+            enable_logging=self.enable_logging,
         )
 
     def write_query_results_to_destination(
@@ -297,7 +309,14 @@ class BigqueryOperator(object):
         if sql_params is None:
             sql_params = dict()
         sql = read_sql(sql_file=sql_file, **sql_params)
-        return query(self.client, job_config, sql, timeout, location)
+        return query(
+            self.client,
+            job_config,
+            sql,
+            timeout,
+            location,
+            self.enable_logging,
+        )
 
     def get_query_results(
         self,
@@ -312,7 +331,7 @@ class BigqueryOperator(object):
         """
         Runs query and returns the result as dataframe
 
-        :param return_type: file format to be returned (dict,dataframe,csv,json,json_string,pyarrow); default is dataframe
+        :param return_type: file format to be returned (dict,dataframe,csv,json,json_string,pyarrow, rowIterator); default is dataframe
         :param sql_file: relative location of sql file to read sql from
         :param sql_params: sql parameters dictionary
         :param timeout: query timeout duration in seconds
@@ -406,6 +425,7 @@ class BigqueryOperator(object):
             sql=sql,
             timeout=timeout,
             location=location,
+            enable_logging=self.enable_logging,
         )
 
     def archive(
@@ -523,9 +543,9 @@ class BigqueryOperator(object):
         :param table_name: Table name to insert rows
         :param data: Data to be inserted into the table
         :return: Sequence[Sequence[Mappings]]: A list with insert errors for each insert chunk.
-        :raises: ValueError: if table's schema is not set
+        :raise: ValueError: if table's schema is not set
         """
-        table_ref = get_table_ref(client, dataset_id, table_name)
+        table_ref = get_table_ref(self.client, dataset_id, table_name)
         table = self.client.get_table(table_ref)
         return self.client.insert_rows_from_dataframe(table, data)
 
@@ -555,4 +575,90 @@ class BigqueryOperator(object):
         table_ref = get_table_ref(self.client, dataset_id, table_name)
         return self.client.load_table_from_dataframe(
             data, table_ref, job_config=job_config
+        )
+
+    def load_to_table_from_json(
+        self,
+        dataset_id: str,
+        table_name: str,
+        write_disposition: str,
+        data,
+    ):
+        """
+        Loads json to the specified table. Returns list of errors for each row
+
+        :param dataset_id: Bigquery dataset id
+        :param table_name: Table name to insert rows
+        :param write_disposition: write disposition of query results
+        :param data: Data to be inserted into the table
+        :return This instance:
+        :raises: ValueError: If a usable parquet engine cannot be found. This method requires :mod:`pyarrow` to be installed
+        """
+        job_config = get_job_config(
+            job_priority="",
+            write_disposition=write_disposition,
+            job_config_str="LoadJobConfig",
+        )
+
+        table_ref = get_table_ref(self.client, dataset_id, table_name)
+        return self.client.load_table_from_json(
+            data, table_ref, job_config=job_config
         ).result()
+
+    def cancel_job(
+        self, job_id: str
+    ) -> Union[job.LoadJob, job.CopyJob, job.ExtractJob, job.QueryJob]:
+        """
+        Cancels given bigquery job.
+
+        :param job_id: Job id to be cancelled
+        :return: Union[
+                google.cloud.bigquery.job.LoadJob,
+                google.cloud.bigquery.job.CopyJob,
+                google.cloud.bigquery.job.ExtractJob,
+                google.cloud.bigquery.job.QueryJob,
+            ]:
+                Job instance, based on the resource returned by the API.
+        """
+        return self.client.cancel_job(job_id=job_id)
+
+    def list_jobs(
+        self,
+        min_creation_time: datetime,
+        max_creation_time: datetime,
+        state_filter: str = STATE_FILTER,
+        all_users: bool = True,
+    ) -> page_iterator.Iterator:
+        """
+        Lists all jobs based on given state parameter and creation time intervals.
+
+        :param min_creation_time:
+        :param max_creation_time:
+        :param state_filter: Job state filter. One of: "done", "pending", "running". Defaults to "running".
+        :param all_users: If true, include jobs owned by all users in the project. Defaults to true.
+        :return: google.api_core.page_iterator.Iterator: Iterable of job instances.
+        :raises: ValueError: If on ``state_filter`` value is invalid
+        """
+        if state_filter not in STATE_FILTERS:
+            raise ValueError(
+                "Invalid state filter: {}. Acceptable values are {}".format(
+                    state_filter, STATE_FILTERS
+                )
+            )
+        return self.client.list_jobs(
+            state_filter=state_filter,
+            min_creation_time=min_creation_time,
+            max_creation_time=max_creation_time,
+            all_users=all_users,
+        )
+
+    def drop_table(self, table_id: str, not_found_ok: bool = False):
+        """
+        Deletes specified table from bigquery.
+
+        :param table_id: Bigquery table id to delete.
+        :param not_found_ok: If false, raises an exception when the table does not exist. Defaults to false.
+        :raises: google.api_core.exceptions.NotFound: If given table id does not exist unless not_found_ok is true.
+        :return:
+        """
+        self.client.delete_table(table_id, not_found_ok=not_found_ok)
