@@ -3,7 +3,7 @@ from google.cloud import bigquery
 
 MEGABYTES_BILLED_DENOMINATOR = 2**20
 AVAILABLE_COLUMN_NAMES = ["column_name", "table_name"]
-SELECT_RETURN_TYPES = ["dict", "json", "dataframe", "pyarrow"]
+SELECT_RETURN_TYPES = ["dict", "json", "dataframe", "pyarrow", "rowIterator"]
 PRIMITIVE_DATA_TYPES = [
     "BOOL",
     "BYTES",
@@ -20,8 +20,8 @@ PRIMITIVE_DATA_TYPES = [
 ]
 JOB_PRIORITIES = ["INTERACTIVE", "BATCH"]
 WRITE_DISPOSITIONS = ["WRITE_APPEND", "WRITE_TRUNCATE", "WRITE_EMPTY"]
-
 JOB_CONFIGS = {
     "LoadJobConfig": bigquery.LoadJobConfig(),
     "QueryJobConfig": bigquery.QueryJobConfig(),
 }
+STATE_FILTERS = ["done", "pending", "running"]
