@@ -1,5 +1,3 @@
-import logging
-
 from google.cloud import bigquery
 from datetime import datetime
 import json
@@ -75,6 +73,7 @@ def query(
     sql: str,
     timeout: int,
     location: str,
+    enable_logging: bool = False,
 ):
     """
     Runs a query with given job configs, and returns job result.
@@ -84,13 +83,16 @@ def query(
     :param sql: sql query
     :param timeout: timeout configuration
     :param location: location
+    :param enable_logging: boolean value for enabling to log queries, by default is false
     :return: job result
     """
     timer_start = datetime.now()
+    if enable_logging:
+        logger.info(f"SQL to run:  {sql} ##")
     query_job = client.query(
         sql, location=location, timeout=timeout, job_config=job_config
     )
-    result = query_job.result()
+    result = query_job.result(timeout=timeout)
     timer_end = datetime.now()
     if query_job.state == "DONE":
         logger.info(
@@ -184,8 +186,6 @@ def select(
         )
     elif return_type == "dict":
         df = result.to_dataframe()
-        print("-----------------mem usage------------------------")
-        print(df.memory_usage())
         return df.to_dict(orient="records")
     elif return_type == "dataframe":
         return result.to_dataframe()
@@ -196,6 +196,8 @@ def select(
             return result.to_dataframe().to_csv()
     elif return_type == "pyarrow":
         return result.to_arrow()
+    elif return_type == "rowIterator":
+        return result
     else:
         raise ValueError(
             "Invalid requested return type:{}. Acceptable return types are ".format(
