@@ -1,7 +1,8 @@
-import sqlalchemy
+from sqlalchemy import create_engine
+from sqlalchemy.orm import sessionmaker
 
 
-def get_db_engine(
+def get_session(
     username: str,
     password: str,
     host: str,
@@ -19,5 +20,7 @@ def get_db_engine(
         username=username, password=password, host=host, dbname=db_name
     )
 
-    engine = sqlalchemy.create_engine(db_connection_str)
-    return engine
+    engine = create_engine(db_connection_str)
+    session = sessionmaker(engine)
+
+    return session
