@@ -7,3 +7,7 @@ TARGET_PREFIX = "T."
 WHITE_SPACE = " "
 SQL_QUOTATION = "`"
 QUESTION_MARK = "?"
+OPEN_PARENTHESIS = "("
+CLOSE_PARENTHESIS = ")"
+DOUBLE_QUOTE = '"'
+DOT = "."
